@@ -1,5 +1,5 @@
 /*
-   Copyright (c) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -19,12 +19,10 @@
 
 #include "gravatarconfiguresettingsdialogtest.h"
 #include "../src/widgets/gravatarconfiguresettingsdialog.h"
-#include <QCheckBox>
-#include <QLabel>
-#include <QPushButton>
-#include <KPluralHandlingSpinBox>
+#include "../src/widgets/gravatarconfiguresettingswidget.h"
+#include <QDialogButtonBox>
 #include <QTest>
-#include <KSeparator>
+#include <QVBoxLayout>
 
 GravatarConfigureSettingsDialogTest::GravatarConfigureSettingsDialogTest(QObject *parent)
     : QObject(parent)
@@ -38,31 +36,14 @@ GravatarConfigureSettingsDialogTest::~GravatarConfigureSettingsDialogTest()
 void GravatarConfigureSettingsDialogTest::shouldHaveDefaultValue()
 {
     Gravatar::GravatarConfigureSettingsDialog dlg;
-    QCheckBox *useDefaultImage = dlg.findChild<QCheckBox *>(QStringLiteral("usedefaultimage"));
-    QVERIFY(useDefaultImage);
+    Gravatar::GravatarConfigureSettingsWidget *configurewidget = dlg.findChild<Gravatar::GravatarConfigureSettingsWidget *>(QStringLiteral("gravatarconfiguresettings"));
+    QVERIFY(configurewidget);
 
-    QPushButton *clearGravatarCache = dlg.findChild<QPushButton *>(QStringLiteral("cleargravatarcachebutton"));
-    QVERIFY(clearGravatarCache);
+    QVBoxLayout *topLayout = dlg.findChild<QVBoxLayout *>(QStringLiteral("toplayout"));
+    QVERIFY(topLayout);
 
-    QLabel *lab = dlg.findChild<QLabel *>(QStringLiteral("gravatarcachesizelabel"));
-    QVERIFY(lab);
-
-    KPluralHandlingSpinBox *gravatarCacheSize = dlg.findChild<KPluralHandlingSpinBox *>(QStringLiteral("gravatarcachesize"));
-    QVERIFY(gravatarCacheSize);
-
-    QCheckBox *useLibravatar = dlg.findChild<QCheckBox *>(QStringLiteral("uselibravatarcheckbox"));
-    QVERIFY(useLibravatar);
-    QVERIFY(useLibravatar->isEnabled());
-
-    QCheckBox *fallbackGravatar = dlg.findChild<QCheckBox *>(QStringLiteral("fallbackgravatar"));
-    QVERIFY(fallbackGravatar);
-    QVERIFY(!fallbackGravatar->isEnabled());
-
-    KSeparator *separator = dlg.findChild<KSeparator *>(QStringLiteral("separator"));
-    QVERIFY(separator);
-
-    KSeparator *separator2 = dlg.findChild<KSeparator *>(QStringLiteral("separator2"));
-    QVERIFY(separator2);
+    QDialogButtonBox *buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
+    QVERIFY(buttonBox);
 }
 
 QTEST_MAIN(GravatarConfigureSettingsDialogTest)
