@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -20,7 +20,7 @@
 #include "gravatarconfigwidgettest.h"
 #include "../src/widgets/gravatarconfigwidget.h"
 #include <QCheckBox>
-#include <qtest.h>
+#include <QTest>
 #include <QPushButton>
 #include <qtestmouse.h>
 #include <QSignalSpy>
