@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,6 +25,8 @@
 
 namespace Gravatar {
 class GravatarDownloadPixmapWidget;
+
+/** Avatar download dialog. */
 class GRAVATAR_EXPORT GravatarDownloadPixmapDialog : public QDialog
 {
     Q_OBJECT
@@ -32,7 +34,7 @@ public:
     explicit GravatarDownloadPixmapDialog(QWidget *parent = nullptr);
     ~GravatarDownloadPixmapDialog();
 
-    QPixmap gravatarPixmap() const;
+    Q_REQUIRED_RESULT QPixmap gravatarPixmap() const;
 
 private:
     void slotAccepted();
